@@ -1,18 +1,18 @@
-# This file was created automatically by SWIG 1.3.27.
+# This file was created automatically by SWIG 1.3.29.
 # Don't modify this file, modify the SWIG interface instead.
 
 import _audio_alsa
-
+import new
+new_instancemethod = new.instancemethod
 def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
+    if (name == "thisown"): return self.this.own(value)
     if (name == "this"):
-        if isinstance(value, class_type):
-            self.__dict__[name] = value.this
-            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
-            del value.thisown
+        if type(value).__name__ == 'PySwigObject':
+            self.__dict__[name] = value
             return
     method = class_type.__swig_setmethods__.get(name,None)
     if method: return method(self,value)
-    if (not static) or hasattr(self,name) or (name == "thisown"):
+    if (not static) or hasattr(self,name):
         self.__dict__[name] = value
     else:
         raise AttributeError("You cannot add attributes to %s" % self)
@@ -21,10 +21,16 @@ def _swig_setattr(self,class_type,name,value):
     return _swig_setattr_nondynamic(self,class_type,name,value,0)
 
 def _swig_getattr(self,class_type,name):
+    if (name == "thisown"): return self.this.own()
     method = class_type.__swig_getmethods__.get(name,None)
     if method: return method(self)
     raise AttributeError,name
 
+def _swig_repr(self):
+    try: strthis = "proxy of " + self.this.__repr__()
+    except: strthis = ""
+    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)
+
 import types
 try:
     _object = types.ObjectType
@@ -37,7 +43,8 @@ del types
 
 def _swig_setattr_nondynamic_method(set):
     def set_attr(self,name,value):
-        if hasattr(self,name) or (name in ("this", "thisown")):
+        if (name == "thisown"): return self.this.own(value)
+        if hasattr(self,name) or (name == "this"):
             set(self,name,value)
         else:
             raise AttributeError("You cannot add attributes to %s" % self)
@@ -46,21 +53,22 @@ def _swig_setattr_nondynamic_method(set):
 
 class audio_alsa_source_sptr(object):
     """Proxy of C++ audio_alsa_source_sptr class"""
-    def __repr__(self):
-        return "<%s.%s; proxy of C++ boost::shared_ptr<audio_alsa_source > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
-    def __init__(self, *args):
+    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
+    __repr__ = _swig_repr
+    def __init__(self, *args): 
         """
         __init__(self) -> audio_alsa_source_sptr
         __init__(self,  p) -> audio_alsa_source_sptr
         """
-        newobj = _audio_alsa.new_audio_alsa_source_sptr(*args)
-        self.this = newobj.this
-        self.thisown = 1
-        del newobj.thisown
+        this = _audio_alsa.new_audio_alsa_source_sptr(*args)
+        try: self.this.append(this)
+        except: self.this = this
     def __deref__(*args):
         """__deref__(self)"""
         return _audio_alsa.audio_alsa_source_sptr___deref__(*args)
 
+    __swig_destroy__ = _audio_alsa.delete_audio_alsa_source_sptr
+    __del__ = lambda self : None;
     def start(*args):
         """start(self) -> bool"""
         return _audio_alsa.audio_alsa_source_sptr_start(*args)
@@ -109,44 +117,34 @@ class audio_alsa_source_sptr(object):
         """set_detail(self, gr_block_detail_sptr detail)"""
         return _audio_alsa.audio_alsa_source_sptr_set_detail(*args)
 
-    def __del__(self, destroy=_audio_alsa.delete_audio_alsa_source_sptr):
-        """__del__(self)"""
-        try:
-            if self.thisown: destroy(self)
-        except: pass
-
-
-class audio_alsa_source_sptrPtr(audio_alsa_source_sptr):
-    def __init__(self, this):
-        self.this = this
-        if not hasattr(self,"thisown"): self.thisown = 0
-        self.__class__ = audio_alsa_source_sptr
-_audio_alsa.audio_alsa_source_sptr_swigregister(audio_alsa_source_sptrPtr)
+audio_alsa_source_sptr_swigregister = _audio_alsa.audio_alsa_source_sptr_swigregister
+audio_alsa_source_sptr_swigregister(audio_alsa_source_sptr)
 
 
 def audio_alsa_source_block(*args):
-    """audio_alsa_source_block(audio_alsa_source_sptr r) -> gr_block_sptr"""
-    return _audio_alsa.audio_alsa_source_block(*args)
+  """audio_alsa_source_block(audio_alsa_source_sptr r) -> gr_block_sptr"""
+  return _audio_alsa.audio_alsa_source_block(*args)
 audio_alsa_source_sptr.block = lambda self: audio_alsa_source_block (self)
 audio_alsa_source_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())
 
 class audio_alsa_sink_sptr(object):
     """Proxy of C++ audio_alsa_sink_sptr class"""
-    def __repr__(self):
-        return "<%s.%s; proxy of C++ boost::shared_ptr<audio_alsa_sink > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
-    def __init__(self, *args):
+    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
+    __repr__ = _swig_repr
+    def __init__(self, *args): 
         """
         __init__(self) -> audio_alsa_sink_sptr
         __init__(self,  p) -> audio_alsa_sink_sptr
         """
-        newobj = _audio_alsa.new_audio_alsa_sink_sptr(*args)
-        self.this = newobj.this
-        self.thisown = 1
-        del newobj.thisown
+        this = _audio_alsa.new_audio_alsa_sink_sptr(*args)
+        try: self.this.append(this)
+        except: self.this = this
     def __deref__(*args):
         """__deref__(self)"""
         return _audio_alsa.audio_alsa_sink_sptr___deref__(*args)
 
+    __swig_destroy__ = _audio_alsa.delete_audio_alsa_sink_sptr
+    __del__ = lambda self : None;
     def name(*args):
         """name(self) -> string"""
         return _audio_alsa.audio_alsa_sink_sptr_name(*args)
@@ -195,46 +193,31 @@ class audio_alsa_sink_sptr(object):
         """set_detail(self, gr_block_detail_sptr detail)"""
         return _audio_alsa.audio_alsa_sink_sptr_set_detail(*args)
 
-    def __del__(self, destroy=_audio_alsa.delete_audio_alsa_sink_sptr):
-        """__del__(self)"""
-        try:
-            if self.thisown: destroy(self)
-        except: pass
-
-
-class audio_alsa_sink_sptrPtr(audio_alsa_sink_sptr):
-    def __init__(self, this):
-        self.this = this
-        if not hasattr(self,"thisown"): self.thisown = 0
-        self.__class__ = audio_alsa_sink_sptr
-_audio_alsa.audio_alsa_sink_sptr_swigregister(audio_alsa_sink_sptrPtr)
+audio_alsa_sink_sptr_swigregister = _audio_alsa.audio_alsa_sink_sptr_swigregister
+audio_alsa_sink_sptr_swigregister(audio_alsa_sink_sptr)
 
 def source(*args):
+  """
+    source(int sampling_rate, string dev="", bool ok_to_block=True) -> audio_alsa_source_sptr
+    source(int sampling_rate, string dev="") -> audio_alsa_source_sptr
+    source(int sampling_rate) -> audio_alsa_source_sptr
     """
-    source(int sampling_freq, string dev="", double period_time=-1, 
-        int nperiods=-1) -> audio_alsa_source_sptr
-    source(int sampling_freq, string dev="", double period_time=-1) -> audio_alsa_source_sptr
-    source(int sampling_freq, string dev="") -> audio_alsa_source_sptr
-    source(int sampling_freq) -> audio_alsa_source_sptr
-    """
-    return _audio_alsa.source(*args)
+  return _audio_alsa.source(*args)
 
 
 def audio_alsa_sink_block(*args):
-    """audio_alsa_sink_block(audio_alsa_sink_sptr r) -> gr_block_sptr"""
-    return _audio_alsa.audio_alsa_sink_block(*args)
+  """audio_alsa_sink_block(audio_alsa_sink_sptr r) -> gr_block_sptr"""
+  return _audio_alsa.audio_alsa_sink_block(*args)
 audio_alsa_sink_sptr.block = lambda self: audio_alsa_sink_block (self)
 audio_alsa_sink_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())
 
 
 
 def sink(*args):
+  """
+    sink(int sampling_rate, string dev="", bool ok_to_block=True) -> audio_alsa_sink_sptr
+    sink(int sampling_rate, string dev="") -> audio_alsa_sink_sptr
+    sink(int sampling_rate) -> audio_alsa_sink_sptr
     """
-    sink(int sampling_freq, string dev="", double period_time=-1, 
-        int nperiods=-1) -> audio_alsa_sink_sptr
-    sink(int sampling_freq, string dev="", double period_time=-1) -> audio_alsa_sink_sptr
-    sink(int sampling_freq, string dev="") -> audio_alsa_sink_sptr
-    sink(int sampling_freq) -> audio_alsa_sink_sptr
-    """
-    return _audio_alsa.sink(*args)
+  return _audio_alsa.sink(*args)
 
